@@ -1,4 +1,4 @@
-extract = function (data, direction = c("time", "x"), timeorder, xorder) 
+extract <- function (data, direction = c("time", "x"), timeorder, xorder) 
 {
     direction = match.arg(direction)
     if (direction == "time") {
@@ -8,4 +8,4 @@ extract = function (data, direction = c("time", "x"), timeorder, xorder)
         output = extract.x(data = data, xorder = xorder)
     }
     return(output)
-}
\ No newline at end of file
+}
