@@ -1,4 +1,4 @@
-mae = function(forecast, true)
+mae <- function(forecast, true)
 {
     if (length(forecast) != length(true))
         stop("MAE: the lengths of input vectors must be the same.")
